# Fixation dot: 固視点

`fixation_dot (固視点)` プラグインで行えることは `sketchpad (スケッチパッド)` アイテムでも同様に行えますが、固視点だけを表示したい場合には便利です。

以下のオプションを利用することができます:

- `Style (スタイル)` 固視点のスタイルを変更します。
- `Duration (呈示時間)` は正の整数もしくは 'keypress'、'mouseclick'である必要があります。これにより一定時間(m秒)、もしくはキーボード応答があるまで、またマウス応答があるまで固視点を表示します。
- `Foreground color (描画色)` は英語名(例: 'blue')もしくはHTMLカラーコード(例: '#0000FF')である必要があります。
- `Background color (背景色)` は英語名(例: 'blue')もしくはHTMLカラーコード(例: '#0000FF')である必要があります。
- `X` および `Y` 値は固視点の呈示座標を表しています。
